pub struct ScoringConfig {
pub sampling: AnnulusSamplingConfig,
pub annulus_margin: Scalar,
pub min_samples: usize,
pub weight_ringness: Scalar,
pub weight_coverage: Scalar,
}Expand description
Configuration for support scoring.
Fields
sampling: AnnulusSamplingConfigAnnulus sampling configuration.
annulus_margin: ScalarHow much wider than the hypothesized radius to sample (as a fraction).
E.g., 0.3 means sample from 0.7*r to 1.3*r.
min_samples: usizeMinimum number of gradient samples to avoid degeneracy flag.
weight_ringness: ScalarWeight of ringness component in total score.
weight_coverage: ScalarWeight of angular coverage in total score.
Implementations